@@ -4,8 +4,8 @@ Contient la classe chargée de traiter, stocker et manipuler les informations li
 
 import re
 
-from src.BI_parser.bloc import Bloc
-from src.BI_parser.const_regex import REG_w
+from BI_parser.bloc import Bloc
+from BI_parser.const_regex import REG_w
 
 class Commentaire(Bloc):
     '''
